@@ -13,9 +13,11 @@
 #'
 #' Predefined tasks are stored in the [dictionary][mlr3misc::Dictionary] [mlr_tasks].
 #'
-#' @template param_rows
 #' @template param_id
 #' @template param_backend
+#' @template param_rows
+#' @template param_cols
+#' @template param_data_format
 #'
 #' @family Task
 #' @export
@@ -48,22 +50,23 @@ TaskClassif = R6Class("TaskClassif",
       assert_string(target)
       super$initialize(id = id, task_type = "classif", backend = backend, target = target)
 
-      info = self$col_info[id == target]
-      levels = info$levels[[1L]]
+      private$.update_class_property()
 
-      if (info$type != "factor") {
-        stopf("Target column '%s' must be a factor", target)
-      }
-      if (length(levels) < 2L) {
-        stopf("Target column '%s' must have at least two levels", target)
-      }
-
-      self$properties = union(self$properties, if (length(levels) == 2L) "twoclass" else "multiclass")
       if (!is.null(positive)) {
         self$positive = positive
       }
     },
 
+    #' @description
+    #' Calls `$data` from parent class [Task] and ensures that levels of the target column
+    #' are in the right order.
+    #'
+    #' @return Depending on the [DataBackend], but usually a [data.table::data.table()].
+    data = function(rows = NULL, cols = NULL, data_format = "data.table") {
+      data = task_data(self, private, rows, cols, data_format)
+      fix_factor_levels(data, set_names(list(self$class_names), self$target_names))
+    },
+
     #' @description
     #' True response for specified `row_ids`. Format depends on the task type.
     #' Defaults to all rows with role `"use"`.
@@ -71,6 +74,18 @@ TaskClassif = R6Class("TaskClassif",
     truth = function(rows = NULL) {
       truth = super$truth(rows)[[1L]]
       as_factor(truth, levels = self$class_names)
+    },
+
+    #' @description
+    #' Updates the cache of stored factor levels, removing all levels not present in the current set of active rows.
+    #' `cols` defaults to all columns with storage type "factor" or "ordered".
+    #' Also updates the task property `"twoclass"`/`"multiclass"`.
+    #'
+    #' @return Modified `self`.
+    droplevels = function(cols = NULL) {
+      super$droplevels()
+      private$.update_class_property()
+      invisible(self)
     }
   ),
 
@@ -112,5 +127,17 @@ TaskClassif = R6Class("TaskClassif",
       }
       return(lvls[2L])
     }
+  ),
+
+  private = list(
+    .update_class_property = function() {
+      nlvls = length(self$class_names)
+      if (nlvls < 2L) {
+        stopf("Target column '%s' must have at least two levels", self$target_names)
+      }
+
+      private$.properties = setdiff(private$.properties, c("twoclass", "multiclass"))
+      private$.properties = union(private$.properties, if (nlvls == 2L) "twoclass" else "multiclass")
+    }
   )
 )
