@@ -11,7 +11,7 @@ hash = function(...) {
 ujoin = function(x, y, key) {
   cn = setdiff(intersect(names(x), names(y)), key)
   expr = parse(text = paste0("`:=`(", paste0(sprintf("%1$s=i.%1$s", cn), collapse = ","), ")"))
-  x[y, eval(expr), on = key]
+  x[y, eval(expr), on = key][]
 }
 
 translate_types = function(x) {
