@@ -12,7 +12,6 @@
 #
 # NB: Extension packages need to specialize the S3 methods in the file.
 
-
 generate_generic_tasks = function(learner, proto) {
   tasks = list()
 
@@ -55,7 +54,9 @@ generate_generic_tasks = function(learner, proto) {
   }
 
   # make sure that task ids match list names
-  mlr3misc::imap(tasks, function(x, n) { x$id = n; x })
+  mlr3misc::imap(tasks, function(x, n) {
+    x$id = n; x
+  })
 }
 
 generate_data = function(learner, N) {
@@ -244,7 +245,7 @@ run_experiment = function(task, learner, seed = NULL) {
   if (!isTRUE(msg))
     return(err(msg))
 
-  if(learner$predict_type == "response"){
+  if (learner$predict_type == "response") {
     msg = checkmate::check_set_equal(learner$predict_type, prediction$predict_types)
     if (!isTRUE(msg))
       return(err(msg))
@@ -323,9 +324,9 @@ run_autotest = function(learner, N = 30L, exclude = NULL, predict_types = learne
           return(repeated_run)
         }
 
-        if (!all.equal(as.data.table(run$prediction), as.data.table(repeated_run$prediction))) {
+        if (!isTRUE(all.equal(as.data.table(run$prediction), as.data.table(repeated_run$prediction)))) {
           run$ok = FALSE
-          run$error = sprintf("Different results for replicated runs using fixed seed %i", seed)
+          run$error = sprintf("Different results for replicated runs using fixed seed %i", run$seed)
           return(run)
         }
       }
@@ -334,3 +335,68 @@ run_autotest = function(learner, N = 30L, exclude = NULL, predict_types = learne
 
   return(TRUE)
 }
+
+#' @title Check Parameters of mlr3 Learners
+#' @description Checks parameters of mlr3learners against parameters defined in
+#'   the upstream functions of the respective learners.
+#'
+#' @details
+#' Some learners do not have all of their parameters stored within the learner
+#' function that is called within `.train()`. Sometimes learners come with a
+#' "control" function, e.g. [glmnet::glmnet.control()]. Such need to be checked
+#' as well since they make up the full ParamSet of the respective learner.
+#'
+#' To work nicely with the defined ParamSet, certain parameters need to be
+#' excluded because these are only present in either the "control" object or the
+#' actual top-level function call. Such exclusions should go into argument
+#' `exclude` with a comment for the reason of the exclusion. See examples for
+#' more information.
+#'
+#' @param learner ([mlr3::Learner])\cr
+#'   The constructed learner.
+#' @param fun (`function`)\cr
+#'   The function of the upstream package for which parameters should
+#'   be checked. E.g. `mboost::boost_control`.
+#' @exclude (`character()`)\cr
+#'   Parameters which should be excluded for this particular check. See details.
+#' @examples
+#' test_that("classif.gamboost", {
+#'   learner = lrn("classif.gamboost")
+#'   fun = mboost::gamboost
+#'   exclude = c(
+#'     "formula", # .train
+#'     "data", # .train
+#'     "na.action", # Only na.omit and na.fail available
+#'     "weights", # .train
+#'     "control" # mboost::boost_control
+#'   )
+#'
+#'   run_paramtest(learner, fun, exclude)
+#'   expect_true(result, info = result$error)
+#' })
+run_paramtest = function(learner, fun, exclude = character()) {
+  par_learner = learner$param_set$ids()
+  par_package = formalArgs(fun)
+
+  missing = setdiff(par_package, par_learner)
+  missing = setdiff(missing, c(exclude, "..."))
+
+  if (length(missing) == 0L)
+    return(TRUE)
+
+  error = sprintf("Missing parameters for learner '%s': %s",
+    learner$id, paste0(missing, collapse = ", "))
+  list(ok = FALSE, error = error, missing = missing)
+}
+
+# Helper function to convert a vector of probabilities to a matrix
+#
+# sometimes useful in tests, e.g., mlr3learners.partykit::LearnerClassifMob
+# uses this in its tests to set up its custom prediction function for a mob
+# version of a logit model
+prob_vector_to_matrix = function(p, levs) {
+  stopifnot(is.numeric(p))
+  y = matrix(c(1 - p, p), ncol = 2L, nrow = length(p))
+  colnames(y) = levs
+  y
+}
