@@ -257,3 +257,19 @@ test_that("filter", {
   bmr$filter(resampling_ids = "cv")
   expect_data_table(bmr$data, nrows = 3)
 })
+
+test_that("parallelization works", {
+  skip_if_not_installed("future")
+  skip_if_not_installed("future.apply")
+  skip_on_os("windows") # currently buggy
+
+  grid = benchmark_grid(list(tsk("wine"), tsk("sonar")), replicate(2, lrn("classif.debug")), rsmp("cv", folds = 2))
+  njobs = 3L
+  bmr = with_future(future::multisession,  {
+    benchmark(grid, store_models = TRUE)
+  }, workers = njobs)
+
+  expect_benchmark_result(bmr)
+  pids = map_int(bmr$data$learner, function(x) x$model$pid)
+  expect_equal(length(unique(pids)), njobs)
+})
